import network, urequests, utime, machine
from machine import Pin
import json

ssid = "your_SSID" 
pw = "your_password"
url_time = "http://worldtimeapi.org/api/timezone/Europe/Brussels"
url_sunrise_set = "https://api.sunrise-sunset.org/json?lat=51.16697&lng=4.45127&formatted=0"
filename = 'status_flag.json'
beeper = Pin(12,Pin.OUT)
up_relay = Pin(4,Pin.OUT)
down_relay = Pin(5,Pin.OUT)

def deep_sleep(msecs):
  rtc = machine.RTC() 
  rtc.irq(trigger=rtc.ALARM0, wake=machine.DEEPSLEEP)
  rtc.alarm(rtc.ALARM0, msecs)
  machine.deepsleep()
  
def get_utc_time():
    time = urequests.get(url_time)
    if time.status_code == 200:
        parsed = time.json()
        datetime_str = str(parsed["utc_datetime"])
        hour = int(datetime_str[11:13])
        minute = int(datetime_str[14:16])
    return hour , minute

def get_sunrise_sunset():
    sunrise_set = urequests.get(url_sunrise_set)
    if sunrise_set.status_code ==200:
        temp = sunrise_set.json()
        parsed = temp["results"]
        sunrise_str = str(parsed["sunrise"])
        sunset_str = str(parsed["sunset"])
        sunrise_hour = int(sunrise_str[11:13])
        sunrise_minute = int(sunrise_str[14:16])
        sunset_hour = int(sunset_str[11:13])
        sunset_minute = int(sunset_str[14:16])
    return sunrise_hour , sunrise_minute , sunset_hour , sunset_minute
  
if machine.reset_cause() != machine.DEEPSLEEP_RESET:
    #power-up ...
    #print("power up ...")
    up = False
    with open(filename, 'w') as f:
        json.dump(up, f)
    deep_sleep(5000)
    
#return from sleep
#print("return from sleep ...")
with open(filename) as f:
    up = json.load(f)
#print("up is :")
#print(up)
wifi = network.WLAN(network.STA_IF) 
wifi.active(True)
wifi.connect(ssid, pw)
while not wifi.isconnected():
    pass
#print("IP:", wifi.ifconfig()[0], "\n")

time = get_utc_time()
rise_set = get_sunrise_sunset()
if (time[0] >= rise_set[0] and time[1] >= rise_set[1]) or (time[0] > rise_set[0]):
    day = True
else:
    day = False
#print(day)
if (time[0] >= rise_set[2] and time[1] >= rise_set[3]) or (time[0] > rise_set[2]):
    day = False
else:
    day = True
#print(day)
if day :
    if up :
        #print("already up ")
        for i in range(2):
            #print(i)
            beeper.on()
            utime.sleep(.5)
            beeper.off()
            utime.sleep(.5)
            #print("done !")
        deep_sleep(600000)
    else :
        #print("up_relay ON")
        beeper.on()
        utime.sleep(2)
        beeper.off()
        up_relay.on()
        utime.sleep(40)
        up_relay.off()
        up = True
        with open(filename, 'w') as f:
            json.dump(up, f)
        deep_sleep(600000)
else :
    if up :
        #print("down relay ON")
        beeper.on()
        utime.sleep(4)
        beeper.off()
        down_relay.on()
        utime.sleep(40)
        down_relay.off()
        up = False
        with open(filename, 'w') as f:
            json.dump(up, f)
        deep_sleep(600000)
    else:
        #print("already down")
        for i in range(4):
            #print(i)
            beeper.on()
            utime.sleep(.5)
            beeper.off()
            utime.sleep(.5)
        deep_sleep(600000)


